@@ -20,6 +20,15 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #---------------------------------------------------------------------------
 from base_device_module import deviceModule
+import time
+import dbus.glib
+"""
+why dbus.glib ?
+if you import only "dbus", it can't find its mainloop for callbacks
+
+"""
+#from dbus.mainloop.glib import DBusGMainLoop
+
 
 def getModule(m,d):
   return(device_n900(m,d))
@@ -32,24 +41,35 @@ class device_n900(deviceModule):
     self.rotationObject = None
     # start the N900 specific automatic GUI rotation support
     self.done = False
+
+    #osso app name
+    self.ossoAppName = 'modrana'
+
+    # screen blanking related
+    self.bus = dbus.SystemBus()
+    self.mceRequest = self.bus.get_object('com.nokia.mce','/com/nokia/mce/request')
+    self.mceSignal = self.bus.get_object('com.nokia.mce','/com/nokia/mce/signal')
+#    self.mceSignalInterface = dbus.Interface(self.mceSignal,'com.nokia.mce.signal')
+#    self.mceSignalInterface.connect_to_signal("display_status_ind", self.screenStateCallback)
+    print "N900: dbus initialized"
+
     print "N900 device specific module initialized"
-    
+
   def firstTime(self):
-    pass
     rotationObject = self.startAutorotation()
     if rotationObject != False:
-      print "N900 rotation object loaded"
+      print "N900: rotation object loaded"
       self.rotationObject = rotationObject
     else:
-      print "N900 loading rotation object failed"
+      print "N900: loading rotation object failed"
 
-    
   def update(self):
     """initialize the automatic rotation"""
     if not self.done:
       if self.topWindow: #TODO: do this more efficiently
         self.startAutorotation()
         self.done = True
+    
 
   def handleMessage(self, message, type, args):
     if message == 'modeChanged':
@@ -58,7 +78,6 @@ class device_n900(deviceModule):
         self.setRotationMode(rotationMode)
         print "rotation mode changed"
 
-
   def getDeviceName(self):
     return "Nokia N900"
 
@@ -66,18 +85,15 @@ class device_n900(deviceModule):
     """start the GUI autorotation feature"""
     try:
       from n900_maemo5_portrait import FremantleRotation
-      app_name = 'modrana' # the name this app
       rotationMode = self.get('rotationMode', "auto") # get last used mode
       lastModeNumber = self.getRotationModeNumber(rotationMode) # get last used mode number
-      rotationObject = FremantleRotation(app_name, main_window=self.topWindow, mode=lastModeNumber)
+      rotationObject = FremantleRotation(self.ossoAppName, main_window=self.topWindow, mode=lastModeNumber)
       self.rotationObject = rotationObject
       print "N900 rotation object initialized"
     except Exception, e:
       print e
       print "intializing N900 rotation object failed"
 
-
-
   def setRotationMode(self, rotationMode):
     rotationModeNumber = self.getRotationModeNumber(rotationMode)
     self.rotationObject.set_mode(rotationModeNumber)
@@ -94,15 +110,22 @@ class device_n900(deviceModule):
     return "/home/user/MyDocs/modrana_debug_log/" #N900 specific log folder
 
   def getPOIFolderPath(self):
-    """override the default method with a N900 specific one"""
+    """get the N900 specific POI folder path"""
     return "/home/user/MyDocs/.maps/"
 
+  def screenBlankingControlSupported(self):
+    """it is possible to controll screen balnking on the N900"""
+    return True
 
-    
+  def pauseScreenBlanking(self):
+    self.mceRequest.req_display_blanking_pause()
 
+  def unlockScreen(self):
+    self.mceRequest.req_tklock_mode_change('unlocked')
 
-
-  
+#  def screenStateCallback(self, state):
+#    print "DISPLAY STATE"
+#    print state
 
 if(__name__ == "__main__"):
   a = n900({}, {})
