@@ -35,10 +35,6 @@ class askMenu(ranaModule):
   def firstTime(self):
     self.menus = self.m.get('menu', None)
 
-  def update(self):
-    # Get and set functions are used to access global data
-    self.set('num_updates', self.get('num_updates', 0) + 1)
-    #print "Updated %d times" % (self.get('num_updates'))
 
   def drawMenu(self, cr, menuName):
     if menuName == 'askYesNo':
